==> zio-aws-serverlessapplicationrepository_2.13-5.17.125.1-sources.jar: zio/aws/serverlessapplicationrepository/model/ParameterValue.scala <==
package zio.aws.serverlessapplicationrepository.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.serverlessapplicationrepository.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class ParameterValue(name: __string, value: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.serverlessapplicationrepository.model.ParameterValue = {
    import ParameterValue.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.serverlessapplicationrepository.model.ParameterValue
      .builder()
      .name(__string.unwrap(name): java.lang.String)
      .value(__string.unwrap(value): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.serverlessapplicationrepository.model.ParameterValue.ReadOnly =
    zio.aws.serverlessapplicationrepository.model.ParameterValue
      .wrap(buildAwsValue())
}
object ParameterValue {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.serverlessapplicationrepository.model.ParameterValue
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.serverlessapplicationrepository.model.ParameterValue =
      zio.aws.serverlessapplicationrepository.model.ParameterValue(name, value)
    def name: __string
    def value: __string
    def getName: ZIO[Any, Nothing, __string] = ZIO.succeed(name)
    def getValue: ZIO[Any, Nothing, __string] = ZIO.succeed(value)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.ParameterValue
  ) extends zio.aws.serverlessapplicationrepository.model.ParameterValue.ReadOnly {
    override val name: __string =
      zio.aws.serverlessapplicationrepository.model.primitives
        .__string(impl.name())
    override val value: __string =
      zio.aws.serverlessapplicationrepository.model.primitives
        .__string(impl.value())
  }
  def wrap(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.ParameterValue
  ): zio.aws.serverlessapplicationrepository.model.ParameterValue.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-serverlessapplicationrepository_2.13-5.17.158.2-sources.jar: zio/aws/serverlessapplicationrepository/model/ParameterValue.scala <==
package zio.aws.serverlessapplicationrepository.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.serverlessapplicationrepository.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class ParameterValue(name: __string, value: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.serverlessapplicationrepository.model.ParameterValue = {
    import ParameterValue.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.serverlessapplicationrepository.model.ParameterValue
      .builder()
      .name(name: java.lang.String)
      .value(value: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.serverlessapplicationrepository.model.ParameterValue.ReadOnly =
    zio.aws.serverlessapplicationrepository.model.ParameterValue
      .wrap(buildAwsValue())
}
object ParameterValue {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.serverlessapplicationrepository.model.ParameterValue
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.serverlessapplicationrepository.model.ParameterValue =
      zio.aws.serverlessapplicationrepository.model.ParameterValue(name, value)
    def name: __string
    def value: __string
    def getName: ZIO[Any, Nothing, __string] = ZIO.succeed(name)
    def getValue: ZIO[Any, Nothing, __string] = ZIO.succeed(value)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.ParameterValue
  ) extends zio.aws.serverlessapplicationrepository.model.ParameterValue.ReadOnly {
    override val name: __string = impl.name(): __string
    override val value: __string = impl.value(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.ParameterValue
  ): zio.aws.serverlessapplicationrepository.model.ParameterValue.ReadOnly =
    new Wrapper(impl)
}
